diff -ur orig/worklogplugin/0.10/worklog/api.py worklogplugin/0.10/worklog/api.py
--- orig/worklogplugin/0.10/worklog/api.py	Thu Aug  9 19:48:58 2007
+++ worklogplugin/0.10/worklog/api.py	Fri Oct 19 18:49:25 2007
@@ -76,7 +76,7 @@
             if self.db_installed_version < 1:
                 print 'Creating work_log table'
                 cursor.execute('CREATE TABLE work_log ('
-                               'user       TEXT,'
+                               'username   TEXT,'
                                'ticket     INTEGER,'
                                'lastchange INTEGER,'
                                'starttime  INTEGER,'
Common subdirectories: orig/worklogplugin/0.10/worklog/htdocs and worklogplugin/0.10/worklog/htdocs
diff -ur orig/worklogplugin/0.10/worklog/manager.py worklogplugin/0.10/worklog/manager.py
--- orig/worklogplugin/0.10/worklog/manager.py	Fri Oct 19 19:03:18 2007
+++ worklogplugin/0.10/worklog/manager.py	Fri Oct 19 18:53:05 2007
@@ -140,7 +140,7 @@
             self.explanation = ''
  
         cursor = db.cursor()
-        cursor.execute('INSERT INTO work_log (user, ticket, lastchange, starttime, endtime) '
+        cursor.execute('INSERT INTO work_log (username, ticket, lastchange, starttime, endtime) '
                        'VALUES (%s, %s, %s, %s, %s)',
                        (self.authname, ticket, self.now, self.now, 0))
         db.commit()
@@ -169,7 +169,7 @@
         cursor = db.cursor()
         cursor.execute('UPDATE work_log '
                        'SET endtime=%s, lastchange=%s, comment=%s '
-                       'WHERE user=%s AND lastchange=%s AND endtime=0',
+                       'WHERE username=%s AND lastchange=%s AND endtime=0',
                        (stoptime, stoptime, comment, self.authname, active['lastchange']))
         db.commit()
 
@@ -219,7 +219,7 @@
     def who_is_working_on(self, ticket):
         db = self.env.get_db_cnx()
         cursor = db.cursor()
-        cursor.execute('SELECT user,starttime FROM work_log WHERE ticket=%s AND endtime=0', (ticket,))
+        cursor.execute('SELECT username,starttime FROM work_log WHERE ticket=%s AND endtime=0', (ticket,))
         try:
             who,since = cursor.fetchone()
             return who,float(since)
@@ -236,7 +236,7 @@
 
         db = self.env.get_db_cnx()
         cursor = db.cursor()
-        cursor.execute('SELECT MAX(lastchange) FROM work_log WHERE user=%s', (self.authname,))
+        cursor.execute('SELECT MAX(lastchange) FROM work_log WHERE username=%s', (self.authname,))
         row = cursor.fetchone()
         if not row or not row[0]:
             return None
@@ -244,16 +244,16 @@
         lastchange = row[0]
     
         task = {}
-        cursor.execute('SELECT wl.user, wl.ticket, t.summary, wl.lastchange, wl.starttime, wl.endtime, wl.comment '
+        cursor.execute('SELECT wl.username, wl.ticket, t.summary, wl.lastchange, wl.starttime, wl.endtime, wl.comment '
                        'FROM work_log wl '
                        'LEFT JOIN ticket t ON wl.ticket=t.id '
-                       'WHERE wl.user=%s AND wl.lastchange=%s', (self.authname, lastchange))
+                       'WHERE wl.username=%s AND wl.lastchange=%s', (self.authname, lastchange))
 
-        for user,ticket,summary,lastchange,starttime,endtime,comment in cursor:
+        for username,ticket,summary,lastchange,starttime,endtime,comment in cursor:
             if not comment:
                 comment = ''
             
-            task['user'] = user
+            task['username'] = username
             task['ticket'] = ticket
             task['summary'] = summary
             task['lastchange'] = float(lastchange)
@@ -278,36 +278,36 @@
         db = self.env.get_db_cnx()
         cursor = db.cursor()
         if mode == 'user':
-            cursor.execute('SELECT wl.user, s.value, wl.starttime, wl.endtime, wl.ticket, t.summary, t.status, wl.comment '
+            cursor.execute('SELECT wl.username, s.value, wl.starttime, wl.endtime, wl.ticket, t.summary, t.status, wl.comment '
                            'FROM work_log wl '
                            'INNER JOIN ticket t ON wl.ticket=t.id '
-                           'LEFT JOIN session_attribute s ON wl.user=s.sid AND s.name=\'name\' '
-                           'WHERE wl.user=%s '
+                           'LEFT JOIN session_attribute s ON wl.username=s.sid AND s.name=\'name\' '
+                           'WHERE wl.username=%s '
                            'ORDER BY wl.lastchange DESC', (self.authname,))
         elif mode == 'summary':
-            cursor.execute('SELECT wl.user, s.value, wl.starttime, wl.endtime, wl.ticket, t.summary, t.status, wl.comment '
-                           'FROM (SELECT user,MAX(lastchange) lastchange FROM work_log GROUP BY user) wlt '
-                           'INNER JOIN work_log wl ON wlt.user=wl.user AND wlt.lastchange=wl.lastchange '
+            cursor.execute('SELECT wl.username, s.value, wl.starttime, wl.endtime, wl.ticket, t.summary, t.status, wl.comment '
+                           'FROM (SELECT username,MAX(lastchange) lastchange FROM work_log GROUP BY username) wlt '
+                           'INNER JOIN work_log wl ON wlt.username=wl.username AND wlt.lastchange=wl.lastchange '
                            'INNER JOIN ticket t ON wl.ticket=t.id '
-                           'LEFT JOIN session_attribute s ON wl.user=s.sid AND s.name=\'name\' '
-                           'ORDER BY wl.lastchange DESC, wl.user')
+                           'LEFT JOIN session_attribute s ON wl.username=s.sid AND s.name=\'name\' '
+                           'ORDER BY wl.lastchange DESC, wl.username')
         else:
-            cursor.execute('SELECT wl.user, s.value, wl.starttime, wl.endtime, wl.ticket, t.summary, t.status, wl.comment '
+            cursor.execute('SELECT wl.username, s.value, wl.starttime, wl.endtime, wl.ticket, t.summary, t.status, wl.comment '
                            'FROM work_log wl '
                            'INNER JOIN ticket t ON wl.ticket=t.id '
-                           'LEFT JOIN session_attribute s ON wl.user=s.sid AND s.name=\'name\' '
-                           'ORDER BY wl.lastchange DESC, wl.user')
+                           'LEFT JOIN session_attribute s ON wl.username=s.sid AND s.name=\'name\' '
+                           'ORDER BY wl.lastchange DESC, wl.username')
         
         rv = []
-        for user,name,starttime,endtime,ticket,summary,status,comment  in cursor:
+        for username,name,starttime,endtime,ticket,summary,status,comment  in cursor:
             starttime = float(starttime)
             endtime = float(endtime)
             
             started = datetime.fromtimestamp(starttime)
             
-            dispname = user
+            dispname = username
             if name:
-                dispname = '%s (%s)' % (name, user)
+                dispname = '%s (%s)' % (name, username)
             
             if not endtime == 0:
                 finished = datetime.fromtimestamp(endtime)
@@ -320,7 +320,7 @@
                         (pretty_timedelta(started),
                          format_date(starttime), format_time(starttime))
 
-            rv.append({'user': user,
+            rv.append({'username': username,
                        'name': name,
                        'dispname': dispname,
                        'starttime': int(starttime),
Common subdirectories: orig/worklogplugin/0.10/worklog/templates and worklogplugin/0.10/worklog/templates
diff -ur orig/worklogplugin/0.10/worklog/timeline_hook.py worklogplugin/0.10/worklog/timeline_hook.py
--- orig/worklogplugin/0.10/worklog/timeline_hook.py	Wed Oct 17 23:00:32 2007
+++ worklogplugin/0.10/worklog/timeline_hook.py	Fri Oct 19 18:53:31 2007
@@ -28,15 +28,15 @@
             db = self.env.get_db_cnx()
             cursor = db.cursor()
 
-            cursor.execute("""SELECT wl.user,wl.ticket,wl.time,wl.starttime,wl.comment,wl.kind,wl.humankind,t.summary,t.status
+            cursor.execute("""SELECT wl.username,wl.ticket,wl.time,wl.starttime,wl.comment,wl.kind,wl.humankind,t.summary,t.status
                              FROM (
                              
                              SELECT user, ticket, starttime AS time, starttime, comment, 'workstart' AS kind, 'started' AS humankind
                              FROM work_log
 
                              UNION
 
                              SELECT user, ticket, endtime AS time, starttime, comment, 'workstop' AS kind, 'stopped' AS humankind
                              FROM work_log
 
                              ) AS wl
@@ -45,16 +45,16 @@
                            ORDER BY wl.time"""
                            % (start, stop))
             previous_update = None
-            for user,ticket,time,starttime,comment,kind,humankind,summary,status in cursor:
+            for username,ticket,time,starttime,comment,kind,humankind,summary,status in cursor:
                 summary = Markup.escape(summary)
                 time = float(time)
                 starttime = float(starttime)
                 if format == 'rss':
                     title = Markup('%s %s working on Ticket #%s (%s): %s' % \
-                                   (user, humankind, ticket, summary, comment))
+                                   (username, humankind, ticket, summary, comment))
                 else:
                     title = Markup('%s %s working on Ticket <em title="%s">#%s</em>' % \
-                                   (user, humankind, summary, ticket))
+                                   (username, humankind, summary, ticket))
                 message = ''
                 if kind == 'workstop':
                     started = datetime.fromtimestamp(starttime)
@@ -63,6 +63,6 @@
                         message =  wiki_to_oneliner(comment, self.env, req, shorten=True) + Markup('<br />(Time spent: %s)' % pretty_timedelta(started, finished))
                     else:
                         message = 'Time spent: %s' % pretty_timedelta(started, finished)
-                yield kind, href.ticket(ticket), title, time, user, message
+                yield kind, href.ticket(ticket), title, time, username, message
 
 
@@ -28,15 +28,15 @@
                              FROM (
                              
-                             SELECT user, ticket, starttime AS time, starttime, comment, 'workstart' AS kind, 'started' AS humankind
+                             SELECT username, ticket, starttime AS time, starttime, comment, 'workstart' AS kind, 'started' AS humankind
                              FROM work_log
 
@@ -28,15 +28,15 @@
                              UNION
 
-                             SELECT user, ticket, endtime AS time, starttime, comment, 'workstop' AS kind, 'stopped' AS humankind
+                             SELECT username, ticket, endtime AS time, starttime, comment, 'workstop' AS kind, 'stopped' AS humankind
                              FROM work_log
 
